@@ -352,10 +352,7 @@ class Field(dfu.Field):
 
         vtkdata.tofile(filename)
 
-    def _writeovf(self, filename, representation="text"):
-        f = open(filename, "w")
-
-        # Define header lines.
+    def _writeovf(self, filename, representation="txt"):
         header = ["OOMMF OVF 2.0",
                   "",
                   "Segment count: 1",
@@ -392,26 +389,31 @@ class Field(dfu.Field):
                   "End: Header",
                   ""]
 
-        if representation == "binary":
+        if representation == "bin4":
+            header.append("Begin: Data Binary 4")
+            footer = ["End: Data Binary 4",
+                      "End: Segment"]
+        elif representation == "bin8":
             header.append("Begin: Data Binary 8")
             footer = ["End: Data Binary 8",
                       "End: Segment"]
-        if representation == "text":
+        elif representation == "txt":
             header.append("Begin: Data Text")
             footer = ["End: Data Text",
                       "End: Segment"]
 
+        f = open(filename, "w")
+
         # Write header lines to OOMMF file.
-        for line in header:
-            if not line:
-                f.write("#\n")
-            else:
-                f.write("# " + line + "\n")
-        if representation == "binary":
+        headerstr = "".join(map(lambda line: "# {}\n".format(line), header))
+        f.write(headerstr)
+
+        if representation == "bin8":
             # Close the file and reopen with binary write
-            # appending to end of file.
+            # appending to the end of file.
             f.close()
             f = open(filename, "ab")
+
             # Add the 8 bit binary check value that OOMMF uses
             packarray = [123456789012345.0]
             # Write data lines to OOMMF file.
@@ -438,8 +440,7 @@ class Field(dfu.Field):
                 f.write("\n")
 
         # Write footer lines to OOMMF file.
-        for line in footer:
-            f.write("# " + line + "\n")
+        footerstr = "".join(map(lambda line: "# {}\n".format(line), footer))
+        f.write(footerstr)
 
-        # Close the file.
         f.close()
